@@ -1,6 +1,6 @@
 package Net::SSH2;
 
-our $VERSION = '0.68';
+our $VERSION = '0.71';
 
 use 5.006;
 use strict;
@@ -669,18 +669,34 @@ Net::SSH2 - Support for the SSH 2 protocol via libssh2.
 
   my $ssh2 = Net::SSH2->new();
 
-  $ssh2->connect('example.com') or $ssh2->die_with_error;
+  $ssh2->connect('example.com')
+    or $ssh2->die_with_error;
 
-  $ssh->check_hostkey('ask') or $ssh2->die_with_error;
+  $ssh->check_hostkey('ask')
+    or $ssh2->die_with_error;
 
-  if ($ssh2->auth_keyboard('fizban')) {
-      my $chan = $ssh2->channel();
-      $chan->exec('program');
+  $ssh->auth_publickey($ENV{USER}, "$ENV{HOME}/.ssh/id_rsa.pub", "$ENV{HOME}/.ssh/id_rsa")
+    or $ssh->die_with_error;
 
-      my $sftp = $ssh2->sftp();
-      my $fh = $sftp->open('/etc/passwd') or $sftp->die_with_error;
-      print $_ while <$fh>;
-  }
+  my $chan = $ssh2->channel()
+    or $ssh2->die_with_error;
+
+  $chan->exec('ls')
+    or $ssh2->die_with_error;
+
+  print while <$chan>;
+
+  print "EXIT CODE: ", $chan->exit_status, "\n";
+
+  $chan->close;
+
+  my $sftp = $ssh2->sftp()
+    or $ssh2->die_with_error;;
+
+  my $fh = $sftp->open('/etc/passwd')
+    or $sftp->die_with_error;
+
+  print while <$fh>;
 
 =head1 DESCRIPTION
 
@@ -1188,6 +1204,8 @@ When libssh2 is compiled using OpenSSL as the crypto backend, passing
 this method C<undef> as the public key argument is acceptable (OpenSSL
 is able to extract the public key from the private one).
 
+See also L<Supported key formats>.
+
 =head2 auth_publickey_frommemory ( username, publickey_blob, privatekey_blob [, passphrase ] )
 
 Authenticate using the given public/private key and an optional
@@ -1444,8 +1462,8 @@ Pass 1 to enable, 0 to disable. Debug output is sent to C<STDERR>.
 
 Enable or disable blocking.
 
-A good number of the methods in Net::SSH2/libssh2 can not work in
-non-blocking mode. Some of them may just forcibly enable blocking
+A good number of the methods in C<Net::SSH2>/C<libssh2> can not work
+in non-blocking mode. Some of them may just forcibly enable blocking
 during its execution. A few may even corrupt the SSH session or crash
 the program.
 
@@ -1454,6 +1472,54 @@ caveats, C<write>. See L<Net::SSH2::Channel/write>.
 
 I<Don't hesitate to report any bug you found in that area!>
 
+=head1 INTEROPERABILITY AND OTHER KNOWN ISSUES
+
+=head2 Protocol versions
+
+The underlaying C<libssh2> library does support version 2 of the SSH
+protocol exclusively (hopefully, version 1 usage is almost extinct).
+
+The SFTP client implements version 3 of the SFTP protocol.
+
+=head2 Key formats
+
+Private and public keys can be generated and stored using different
+formats and cyphers. Which ones are accepted by C<Net::SSH2> depends
+on the libssh2 version being used and of the underlying crypto backend
+it was configured to use at build time (OpenSSL C<libssl> or
+C<libgcrypt>).
+
+An increassingly common problem is that OpenSSH since version 7.8
+(released 2018-8-24) generates keys by default using the format
+RFC4716 which is not supported by the default crypto backend
+(C<libssl>).
+
+Keys can be converted inplace to the old PEM format using
+L<ssh-keygen(1)> as follows:
+
+  $ ssh-keygen -p -m PEM -N "" -f ~/.ssh/id_rsa
+
+On Windows, PuTTYgen (which is part of the PuTTY distribution) can be
+used to convert keys.
+
+Another common issue is that in the last years OpenSSH has
+incorporated several new cyphers that are not supported by any version
+of C<libssh2> yet (though the incoming 1.8.1 may aliviate the
+situation). Currently the best option from an interoperability
+standpoint is probably to stick to RSA key usage.
+
+=head2 Security
+
+Nowadays C<libssh2> development is not thrilling; new versions (even
+minor ones) are being released just every two or three years. On the
+other hand security issues are found and reported far more
+frequently. That means that C<Net::SSH2>/C<libssh2> could be an easy
+attack vector.
+
+So, Net::SSH2 should be used only in trusted environments. More
+specifically, using it to connect to untrusted third party computers
+over the Internet is probably a very bad idea!
+
 =head1 SEE ALSO
 
 L<Net::SSH2::Channel>, L<Net::SSH2::Listener>,
@@ -1474,9 +1540,9 @@ L<Net::OpenSSH::Compat>.
 
 Copyright (C) 2005 - 2010 by David B. Robins (dbrobins@cpan.org).
 
-Copyright (C) 2010 - 2016 by Rafael Kitover (rkitover@cpan.org).
+Copyright (C) 2010 - 2020 by Rafael Kitover (rkitover@cpan.org).
 
-Copyright (C) 2011 - 2017 by Salvador FandiE<ntilde>o (salva@cpan.org).
+Copyright (C) 2011 - 2019 by Salvador FandiE<ntilde>o (salva@cpan.org).
 
 All rights reserved.
 
